==> jaxx-application-api-2.11-sources.jar: org/nuiton/jaxx/application/ApplicationConfiguration.java <==
package org.nuiton.jaxx.application;

/*
 * #%L
 * JAXX :: Application API
 * %%
 * Copyright (C) 2008 - 2014 Code Lutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import org.nuiton.config.ApplicationConfig;
import org.nuiton.config.ApplicationConfigHelper;
import org.nuiton.config.ApplicationConfigProvider;
import org.nuiton.util.version.Version;

import javax.swing.KeyStroke;
import java.util.Set;

/**
 * Created on 11/24/13.
 *
 * @author Tony Chemit - chemit@codelutin.com
 * @since 2.8
 */
public abstract class ApplicationConfiguration {

    /**
     * Delegate application config.
     */
    protected final ApplicationConfig applicationConfig;

    public abstract String getApplicationName();

    public abstract Version getVersion();

    public abstract KeyStroke getShortcutClosePopup();

    public ApplicationConfiguration(ApplicationConfig applicationConfig) {
        this.applicationConfig = applicationConfig;
    }

    public ApplicationConfig getApplicationConfig() {
        return applicationConfig;
    }

    public static Set<ApplicationConfigProvider> loadApplicationConfig(ApplicationConfig applicationConfig) {

        // get all config providers
        Set<ApplicationConfigProvider> providers =
                ApplicationConfigHelper.getProviders(null,
                                                     null,
                                                     null,
                                                     true);

        // load all default options
        ApplicationConfigHelper.loadAllDefaultOption(applicationConfig, providers);

        // load actions
        ApplicationConfigHelper.loadAllActions(applicationConfig, providers);

        return providers;
    }
}

==> jaxx-application-api-2.27-sources.jar: org/nuiton/jaxx/application/ApplicationConfiguration.java <==
package org.nuiton.jaxx.application;

/*
 * #%L
 * JAXX :: Application API
 * %%
 * Copyright (C) 2008 - 2014 Code Lutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import org.nuiton.config.ApplicationConfig;
import org.nuiton.config.ApplicationConfigHelper;
import org.nuiton.config.ApplicationConfigProvider;
import org.nuiton.util.version.Version;

import javax.swing.KeyStroke;
import java.util.Set;

/**
 * Created on 11/24/13.
 *
 * @author Tony Chemit - chemit@codelutin.com
 * @since 2.8
 */
public abstract class ApplicationConfiguration {

    /**
     * Delegate application config.
     */
    protected final ApplicationConfig applicationConfig;

    public abstract String getApplicationName();

    public abstract Version getVersion();

    /**
     * @deprecated  since 2.13, use now {@code org.nuiton.jaxx.application.swing.ApplicationUIConfiguration#getShortcutClosePopup()}
     */
    @Deprecated
    public abstract KeyStroke getShortcutClosePopup();

    public ApplicationConfiguration(ApplicationConfig applicationConfig) {
        this.applicationConfig = applicationConfig;
    }

    public ApplicationConfig getApplicationConfig() {
        return applicationConfig;
    }

    public static Set<ApplicationConfigProvider> loadApplicationConfig(ApplicationConfig applicationConfig) {

        // get all config providers
        Set<ApplicationConfigProvider> providers =
                ApplicationConfigHelper.getProviders(null,
                                                     null,
                                                     null,
                                                     true);

        // load all default options
        ApplicationConfigHelper.loadAllDefaultOption(applicationConfig, providers);

        // load actions
        ApplicationConfigHelper.loadAllActions(applicationConfig, providers);

        return providers;
    }
}
